@@ -17,6 +17,10 @@
 *  or make the str argument into a struct. */
 #define BLAS_FORTRAN_STRLEN_END
 
+#ifndef FORTRAN_STRLEN
+  #define FORTRAN_STRLEN size_t
+#endif
+
 #ifdef CRAY
    #include <fortran.h>
    #define F77_CHAR _fcd
@@ -193,24 +197,28 @@
 #define F77_zherk_base        F77_GLOBAL_SUFFIX(zherk,ZHERK)
 #define F77_zher2k_base       F77_GLOBAL_SUFFIX(zher2k,ZHER2K)
 #define F77_sgemm_base        F77_GLOBAL_SUFFIX(sgemm,SGEMM)
+#define F77_sgemmtr_base        F77_GLOBAL_SUFFIX(sgemmtr,SGEMMTR)
 #define F77_ssymm_base        F77_GLOBAL_SUFFIX(ssymm,SSYMM)
 #define F77_ssyrk_base        F77_GLOBAL_SUFFIX(ssyrk,SSYRK)
 #define F77_ssyr2k_base       F77_GLOBAL_SUFFIX(ssyr2k,SSYR2K)
 #define F77_strmm_base        F77_GLOBAL_SUFFIX(strmm,STRMM)
 #define F77_strsm_base        F77_GLOBAL_SUFFIX(strsm,STRSM)
 #define F77_dgemm_base        F77_GLOBAL_SUFFIX(dgemm,DGEMM)
+#define F77_dgemmtr_base        F77_GLOBAL_SUFFIX(dgemmtr,DGEMMTR)
 #define F77_dsymm_base        F77_GLOBAL_SUFFIX(dsymm,DSYMM)
 #define F77_dsyrk_base        F77_GLOBAL_SUFFIX(dsyrk,DSYRK)
 #define F77_dsyr2k_base       F77_GLOBAL_SUFFIX(dsyr2k,DSYR2K)
 #define F77_dtrmm_base        F77_GLOBAL_SUFFIX(dtrmm,DTRMM)
 #define F77_dtrsm_base        F77_GLOBAL_SUFFIX(dtrsm,DTRSM)
 #define F77_cgemm_base        F77_GLOBAL_SUFFIX(cgemm,CGEMM)
+#define F77_cgemmtr_base        F77_GLOBAL_SUFFIX(cgemmtr,CGEMMTR)
 #define F77_csymm_base        F77_GLOBAL_SUFFIX(csymm,CSYMM)
 #define F77_csyrk_base        F77_GLOBAL_SUFFIX(csyrk,CSYRK)
 #define F77_csyr2k_base       F77_GLOBAL_SUFFIX(csyr2k,CSYR2K)
 #define F77_ctrmm_base        F77_GLOBAL_SUFFIX(ctrmm,CTRMM)
 #define F77_ctrsm_base        F77_GLOBAL_SUFFIX(ctrsm,CTRSM)
 #define F77_zgemm_base        F77_GLOBAL_SUFFIX(zgemm,ZGEMM)
+#define F77_zgemmtr_base        F77_GLOBAL_SUFFIX(zgemmtr,ZGEMMTR)
 #define F77_zsymm_base        F77_GLOBAL_SUFFIX(zsymm,ZSYMM)
 #define F77_zsyrk_base        F77_GLOBAL_SUFFIX(zsyrk,ZSYRK)
 #define F77_zsyr2k_base       F77_GLOBAL_SUFFIX(zsyr2k,ZSYR2K)
@@ -385,6 +393,7 @@
    /* Single Precision */
 
    #define F77_sgemm(...)     F77_sgemm_base(__VA_ARGS__, 1, 1)
+   #define F77_sgemmtr(...)    F77_sgemmtr_base(__VA_ARGS__, 1, 1, 1)
    #define F77_ssymm(...)     F77_ssymm_base(__VA_ARGS__, 1, 1)
    #define F77_ssyrk(...)     F77_ssyrk_base(__VA_ARGS__, 1, 1)
    #define F77_ssyr2k(...)    F77_ssyr2k_base(__VA_ARGS__, 1, 1)
@@ -394,6 +403,7 @@
    /* Double Precision */
 
    #define F77_dgemm(...)     F77_dgemm_base(__VA_ARGS__, 1, 1)
+   #define F77_dgemmtr(...)    F77_dgemmtr_base(__VA_ARGS__, 1, 1, 1)
    #define F77_dsymm(...)     F77_dsymm_base(__VA_ARGS__, 1, 1)
    #define F77_dsyrk(...)     F77_dsyrk_base(__VA_ARGS__, 1, 1)
    #define F77_dsyr2k(...)    F77_dsyr2k_base(__VA_ARGS__, 1, 1)
@@ -403,6 +413,7 @@
    /* Single Complex Precision */
 
    #define F77_cgemm(...)     F77_cgemm_base(__VA_ARGS__, 1, 1)
+   #define F77_cgemmtr(...)    F77_cgemmtr_base(__VA_ARGS__, 1, 1, 1)
    #define F77_csymm(...)     F77_csymm_base(__VA_ARGS__, 1, 1)
    #define F77_chemm(...)     F77_chemm_base(__VA_ARGS__, 1, 1)
    #define F77_csyrk(...)     F77_csyrk_base(__VA_ARGS__, 1, 1)
@@ -415,6 +426,7 @@
    /* Double Complex Precision */
 
    #define F77_zgemm(...)     F77_zgemm_base(__VA_ARGS__, 1, 1)
+   #define F77_zgemmtr(...)    F77_zgemmtr_base(__VA_ARGS__, 1, 1, 1)
    #define F77_zsymm(...)     F77_zsymm_base(__VA_ARGS__, 1, 1)
    #define F77_zhemm(...)     F77_zhemm_base(__VA_ARGS__, 1, 1)
    #define F77_zsyrk(...)     F77_zsyrk_base(__VA_ARGS__, 1, 1)
@@ -509,6 +521,7 @@
    /* Single Precision */
 
    #define F77_sgemm(...)     F77_sgemm_base(__VA_ARGS__)
+   #define F77_sgemmtr(...)    F77_sgemmtr_base(__VA_ARGS__)
    #define F77_ssymm(...)     F77_ssymm_base(__VA_ARGS__)
    #define F77_ssyrk(...)     F77_ssyrk_base(__VA_ARGS__)
    #define F77_ssyr2k(...)    F77_ssyr2k_base(__VA_ARGS__)
@@ -518,6 +531,7 @@
    /* Double Precision */
 
    #define F77_dgemm(...)     F77_dgemm_base(__VA_ARGS__)
+   #define F77_dgemmtr(...)    F77_dgemmtr_base(__VA_ARGS__)
    #define F77_dsymm(...)     F77_dsymm_base(__VA_ARGS__)
    #define F77_dsyrk(...)     F77_dsyrk_base(__VA_ARGS__)
    #define F77_dsyr2k(...)    F77_dsyr2k_base(__VA_ARGS__)
@@ -527,6 +541,7 @@
    /* Single Complex Precision */
 
    #define F77_cgemm(...)     F77_cgemm_base(__VA_ARGS__)
+   #define F77_cgemmtr(...)    F77_cgemmtr_base(__VA_ARGS__)
    #define F77_csymm(...)     F77_csymm_base(__VA_ARGS__)
    #define F77_chemm(...)     F77_chemm_base(__VA_ARGS__)
    #define F77_csyrk(...)     F77_csyrk_base(__VA_ARGS__)
@@ -539,6 +554,7 @@
    /* Double Complex Precision */
 
    #define F77_zgemm(...)     F77_zgemm_base(__VA_ARGS__)
+   #define F77_zgemmtr(...)    F77_zgemmtr_base(__VA_ARGS__)
    #define F77_zsymm(...)     F77_zsymm_base(__VA_ARGS__)
    #define F77_zhemm(...)     F77_zhemm_base(__VA_ARGS__)
    #define F77_zsyrk(...)     F77_zsyrk_base(__VA_ARGS__)
@@ -569,7 +585,7 @@ __attribute__((weak))
 #endif
 F77_xerbla_base(FCHAR, void *
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 
@@ -652,78 +668,78 @@ void F77_dcabs1_sub_base(const void *, double *);
 
 void F77_sgemv_base(FCHAR, FINT, FINT, const float *, const float *, FINT, const float *, FINT, const float *, float *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 void F77_sgbmv_base(FCHAR, FINT, FINT, FINT, FINT, const float *,  const float *, FINT, const float *, FINT, const float *, float *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 void F77_ssymv_base(FCHAR, FINT, const float *, const float *, FINT, const float *,  FINT, const float *, float *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 void F77_ssbmv_base(FCHAR, FINT, FINT, const float *, const float *, FINT, const float *, FINT, const float *, float *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 void F77_sspmv_base(FCHAR, FINT, const float *, const float *, const float *, FINT, const float *, float *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 void F77_strmv_base(FCHAR, FCHAR, FCHAR, FINT, const float *, FINT, float *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_stbmv_base(FCHAR, FCHAR, FCHAR, FINT, FINT, const float *, FINT, float *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_strsv_base(FCHAR, FCHAR, FCHAR, FINT, const float *, FINT, float *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_stbsv_base(FCHAR, FCHAR, FCHAR, FINT, FINT, const float *, FINT, float *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_stpmv_base(FCHAR, FCHAR, FCHAR, FINT, const float *, float *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_stpsv_base(FCHAR, FCHAR, FCHAR, FINT, const float *, float *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_sger_base(FINT, FINT, const float *, const float *, FINT, const float *, FINT, float *, FINT);
 void F77_ssyr_base(FCHAR, FINT, const float *, const float *, FINT, float *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 void F77_sspr_base(FCHAR, FINT, const float *, const float *, FINT, float *
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 void F77_sspr2_base(FCHAR, FINT, const float *, const float *, FINT, const float *, FINT,  float *
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 void F77_ssyr2_base(FCHAR, FINT, const float *, const float *, FINT, const float *, FINT,  float *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 
@@ -731,78 +747,78 @@ void F77_ssyr2_base(FCHAR, FINT, const float *, const float *, FINT, const float
 
 void F77_dgemv_base(FCHAR, FINT, FINT, const double *, const double *, FINT, const double *, FINT, const double *, double *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 void F77_dgbmv_base(FCHAR, FINT, FINT, FINT, FINT, const double *,  const double *, FINT, const double *, FINT, const double *, double *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 void F77_dsymv_base(FCHAR, FINT, const double *, const double *, FINT, const double *,  FINT, const double *, double *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 void F77_dsbmv_base(FCHAR, FINT, FINT, const double *, const double *, FINT, const double *, FINT, const double *, double *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 void F77_dspmv_base(FCHAR, FINT, const double *, const double *, const double *, FINT, const double *, double *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 void F77_dtrmv_base(FCHAR, FCHAR, FCHAR, FINT, const double *, FINT, double *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_dtbmv_base(FCHAR, FCHAR, FCHAR, FINT, FINT, const double *, FINT, double *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_dtrsv_base(FCHAR, FCHAR, FCHAR, FINT, const double *, FINT, double *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_dtbsv_base(FCHAR, FCHAR, FCHAR, FINT, FINT, const double *, FINT, double *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_dtpmv_base(FCHAR, FCHAR, FCHAR, FINT, const double *, double *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_dtpsv_base(FCHAR, FCHAR, FCHAR, FINT, const double *, double *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_dger_base(FINT, FINT, const double *, const double *, FINT, const double *, FINT, double *, FINT);
 void F77_dsyr_base(FCHAR, FINT, const double *, const double *, FINT, double *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 void F77_dspr_base(FCHAR, FINT, const double *, const double *, FINT, double *
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 void F77_dspr2_base(FCHAR, FINT, const double *, const double *, FINT, const double *, FINT,  double *
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 void F77_dsyr2_base(FCHAR, FINT, const double *, const double *, FINT, const double *, FINT,  double *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 
@@ -810,79 +826,79 @@ void F77_dsyr2_base(FCHAR, FINT, const double *, const double *, FINT, const dou
 
 void F77_cgemv_base(FCHAR, FINT, FINT, const void *, const void *, FINT, const void *, FINT, const void *, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 void F77_cgbmv_base(FCHAR, FINT, FINT, FINT, FINT, const void *,  const void *, FINT, const void *, FINT, const void *, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 void F77_chemv_base(FCHAR, FINT, const void *, const void *, FINT, const void *, FINT, const void *, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 void F77_chbmv_base(FCHAR, FINT, FINT, const void *, const void *, FINT, const void *, FINT, const void *, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 void F77_chpmv_base(FCHAR, FINT, const void *, const void *, const void *, FINT, const void *, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 void F77_ctrmv_base(FCHAR, FCHAR, FCHAR, FINT, const void *, FINT, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_ctbmv_base(FCHAR, FCHAR, FCHAR, FINT, FINT, const void *, FINT, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_ctpmv_base(FCHAR, FCHAR, FCHAR, FINT, const void *, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_ctrsv_base(FCHAR, FCHAR, FCHAR, FINT, const void *, FINT, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_ctbsv_base(FCHAR, FCHAR, FCHAR, FINT, FINT, const void *, FINT, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_ctpsv_base(FCHAR, FCHAR, FCHAR, FINT, const void *, void *,FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_cgerc_base(FINT, FINT, const void *, const void *, FINT, const void *, FINT, void *, FINT);
 void F77_cgeru_base(FINT, FINT, const void *, const void *, FINT, const void *, FINT, void *,  FINT);
 void F77_cher_base(FCHAR, FINT, const float *, const void *, FINT, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 void F77_cher2_base(FCHAR, FINT, const void *, const void *, FINT, const void *, FINT, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 void F77_chpr_base(FCHAR, FINT, const float *, const void *, FINT, void *
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
-void F77_chpr2_base(FCHAR, FINT, const float *, const void *, FINT, const void *, FINT, void *
+void F77_chpr2_base(FCHAR, FINT, const void *, const void *, FINT, const void *, FINT, void *
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 
@@ -890,79 +906,79 @@ void F77_chpr2_base(FCHAR, FINT, const float *, const void *, FINT, const void *
 
 void F77_zgemv_base(FCHAR, FINT, FINT, const void *, const void *, FINT, const void *, FINT, const void *, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 void F77_zgbmv_base(FCHAR, FINT, FINT, FINT, FINT, const void *,  const void *, FINT, const void *, FINT, const void *, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 void F77_zhemv_base(FCHAR, FINT, const void *, const void *, FINT, const void *, FINT, const void *, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 void F77_zhbmv_base(FCHAR, FINT, FINT, const void *, const void *, FINT, const void *, FINT, const void *, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 void F77_zhpmv_base(FCHAR, FINT, const void *, const void *, const void *, FINT, const void *, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 void F77_ztrmv_base(FCHAR, FCHAR, FCHAR, FINT, const void *, FINT, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_ztbmv_base(FCHAR, FCHAR, FCHAR, FINT, FINT, const void *, FINT, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_ztpmv_base(FCHAR, FCHAR, FCHAR, FINT, const void *, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_ztrsv_base(FCHAR, FCHAR, FCHAR, FINT, const void *, FINT, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_ztbsv_base(FCHAR, FCHAR, FCHAR, FINT, FINT, const void *, FINT, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_ztpsv_base(FCHAR, FCHAR, FCHAR, FINT, const void *, void *,FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_zgerc_base(FINT, FINT, const void *, const void *, FINT, const void *, FINT, void *, FINT);
 void F77_zgeru_base(FINT, FINT, const void *, const void *, FINT, const void *, FINT, void *,  FINT);
 void F77_zher_base(FCHAR, FINT, const double *, const void *, FINT, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 void F77_zher2_base(FCHAR, FINT, const void *, const void *, FINT, const void *, FINT, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 void F77_zhpr_base(FCHAR, FINT, const double *, const void *, FINT, void *
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
-void F77_zhpr2_base(FCHAR, FINT, const double *, const void *, FINT, const void *, FINT, void *
+void F77_zhpr2_base(FCHAR, FINT, const void *, const void *, FINT, const void *, FINT, void *
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t
+   , FORTRAN_STRLEN
 #endif
 );
 
@@ -974,32 +990,38 @@ void F77_zhpr2_base(FCHAR, FINT, const double *, const void *, FINT, const void
 
 void F77_sgemm_base(FCHAR, FCHAR, FINT, FINT, FINT, const float *, const float *, FINT, const float *, FINT, const float *, float *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
+void F77_sgemmtr_base(FCHAR, FCHAR, FCHAR, FINT, FINT, const float *, const float *, FINT, const float *, FINT, const float *, float *, FINT
+#ifdef BLAS_FORTRAN_STRLEN_END
+   , size_t, size_t, size_t
+#endif
+);
+
 void F77_ssymm_base(FCHAR, FCHAR, FINT, FINT, const float *, const float *, FINT, const float *, FINT, const float *, float *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_ssyrk_base(FCHAR, FCHAR, FINT, FINT, const float *, const float *, FINT, const float *, float *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_ssyr2k_base(FCHAR, FCHAR, FINT, FINT, const float *, const float *, FINT, const float *, FINT, const float *, float *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_strmm_base(FCHAR, FCHAR, FCHAR, FCHAR, FINT, FINT, const float *, const float *, FINT, float *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_strsm_base(FCHAR, FCHAR, FCHAR, FCHAR, FINT, FINT, const float *, const float *, FINT, float *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 
@@ -1007,128 +1029,148 @@ void F77_strsm_base(FCHAR, FCHAR, FCHAR, FCHAR, FINT, FINT, const float *, const
 
 void F77_dgemm_base(FCHAR, FCHAR, FINT, FINT, FINT, const double *, const double *, FINT, const double *, FINT, const double *, double *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
+void F77_dgemmtr_base(FCHAR, FCHAR, FCHAR, FINT, FINT, const double *, const double *, FINT, const double *, FINT, const double *, double *, FINT
+#ifdef BLAS_FORTRAN_STRLEN_END
+   , size_t, size_t, size_t
+#endif
+);
+
 void F77_dsymm_base(FCHAR, FCHAR, FINT, FINT, const double *, const double *, FINT, const double *, FINT, const double *, double *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_dsyrk_base(FCHAR, FCHAR, FINT, FINT, const double *, const double *, FINT, const double *, double *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_dsyr2k_base(FCHAR, FCHAR, FINT, FINT, const double *, const double *, FINT, const double *, FINT, const double *, double *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_dtrmm_base(FCHAR, FCHAR, FCHAR, FCHAR, FINT, FINT, const double *, const double *, FINT, double *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 void F77_dtrsm_base(FCHAR, FCHAR, FCHAR, FCHAR, FINT, FINT, const double *, const double *, FINT, double *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 
 /* Single Complex Precision */
 
-void F77_cgemm_base(FCHAR, FCHAR, FINT, FINT, FINT, const float *, const float *, FINT, const float *, FINT, const float *, float *, FINT
+void F77_cgemm_base(FCHAR, FCHAR, FINT, FINT, FINT, const void *, const void *, FINT, const void *, FINT, const void *, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
-void F77_csymm_base(FCHAR, FCHAR, FINT, FINT, const float *, const float *, FINT, const float *, FINT, const float *, float *, FINT
+
+void F77_cgemmtr_base(FCHAR, FCHAR, FCHAR, FINT, FINT, const void *, const void *, FINT, const void *, FINT, const void *, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
-void F77_chemm_base(FCHAR, FCHAR, FINT, FINT, const float *, const float *, FINT, const float *, FINT, const float *, float *, FINT
+
+void F77_csymm_base(FCHAR, FCHAR, FINT, FINT, const void *, const void *, FINT, const void *, FINT, const void *, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
-void F77_csyrk_base(FCHAR, FCHAR, FINT, FINT, const float *, const float *, FINT, const float *, float *, FINT
+void F77_chemm_base(FCHAR, FCHAR, FINT, FINT, const void *, const void *, FINT, const void *, FINT, const void *, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
-void F77_cherk_base(FCHAR, FCHAR, FINT, FINT, const float *, const float *, FINT, const float *, float *, FINT
+void F77_csyrk_base(FCHAR, FCHAR, FINT, FINT, const void *, const void *, FINT, const void *, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
-void F77_csyr2k_base(FCHAR, FCHAR, FINT, FINT, const float *, const float *, FINT, const float *, FINT, const float *, float *, FINT
+void F77_cherk_base(FCHAR, FCHAR, FINT, FINT, const float *, const void *, FINT, const float *, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
-void F77_cher2k_base(FCHAR, FCHAR, FINT, FINT, const float *, const float *, FINT, const float *, FINT, const float *, float *, FINT
+void F77_csyr2k_base(FCHAR, FCHAR, FINT, FINT, const void *, const void *, FINT, const void *, FINT, const void *, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
-void F77_ctrmm_base(FCHAR, FCHAR, FCHAR, FCHAR, FINT, FINT, const float *, const float *, FINT, float *, FINT
+void F77_cher2k_base(FCHAR, FCHAR, FINT, FINT, const void *, const void *, FINT, const void *, FINT, const float *, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
-void F77_ctrsm_base(FCHAR, FCHAR, FCHAR, FCHAR, FINT, FINT, const float *, const float *, FINT, float *, FINT
+void F77_ctrmm_base(FCHAR, FCHAR, FCHAR, FCHAR, FINT, FINT, const void *, const void *, FINT, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
+#endif
+);
+void F77_ctrsm_base(FCHAR, FCHAR, FCHAR, FCHAR, FINT, FINT, const void *, const void *, FINT, void *, FINT
+#ifdef BLAS_FORTRAN_STRLEN_END
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 
 /* Double Complex Precision */
 
-void F77_zgemm_base(FCHAR, FCHAR, FINT, FINT, FINT, const double *, const double *, FINT, const double *, FINT, const double *, double *, FINT
+void F77_zgemm_base(FCHAR, FCHAR, FINT, FINT, FINT, const void *, const void *, FINT, const void *, FINT, const void *, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
-void F77_zsymm_base(FCHAR, FCHAR, FINT, FINT, const double *, const double *, FINT, const double *, FINT, const double *, double *, FINT
+
+void F77_zgemmtr_base(FCHAR, FCHAR, FCHAR, FINT, FINT, const void *, const void *, FINT, const void *, FINT, const void *, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
-void F77_zhemm_base(FCHAR, FCHAR, FINT, FINT, const double *, const double *, FINT, const double *, FINT, const double *, double *, FINT
+
+void F77_zsymm_base(FCHAR, FCHAR, FINT, FINT, const void *, const void *, FINT, const void *, FINT, const void *, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
-void F77_zsyrk_base(FCHAR, FCHAR, FINT, FINT, const double *, const double *, FINT, const double *, double *, FINT
+void F77_zhemm_base(FCHAR, FCHAR, FINT, FINT, const void *, const void *, FINT, const void *, FINT, const void *, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
-void F77_zherk_base(FCHAR, FCHAR, FINT, FINT, const double *, const double *, FINT, const double *, double *, FINT
+void F77_zsyrk_base(FCHAR, FCHAR, FINT, FINT, const void *, const void *, FINT, const void *, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
-void F77_zsyr2k_base(FCHAR, FCHAR, FINT, FINT, const double *, const double *, FINT, const double *, FINT, const double *, double *, FINT
+void F77_zherk_base(FCHAR, FCHAR, FINT, FINT, const double *, const void *, FINT, const double *, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
-void F77_zher2k_base(FCHAR, FCHAR, FINT, FINT, const double *, const double *, FINT, const double *, FINT, const double *, double *, FINT
+void F77_zsyr2k_base(FCHAR, FCHAR, FINT, FINT, const void *, const void *, FINT, const void *, FINT, const void *, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
-void F77_ztrmm_base(FCHAR, FCHAR, FCHAR, FCHAR, FINT, FINT, const double *, const double *, FINT, double *, FINT
+void F77_zher2k_base(FCHAR, FCHAR, FINT, FINT, const void *, const void *, FINT, const void *, FINT, const double *, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
-void F77_ztrsm_base(FCHAR, FCHAR, FCHAR, FCHAR, FINT, FINT, const double *, const double *, FINT, double *, FINT
+void F77_ztrmm_base(FCHAR, FCHAR, FCHAR, FCHAR, FINT, FINT, const void *, const void *, FINT, void *, FINT
 #ifdef BLAS_FORTRAN_STRLEN_END
-   , size_t, size_t, size_t, size_t
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
+#endif
+);
+void F77_ztrsm_base(FCHAR, FCHAR, FCHAR, FCHAR, FINT, FINT, const void *, const void *, FINT, void *, FINT
+#ifdef BLAS_FORTRAN_STRLEN_END
+   , FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN, FORTRAN_STRLEN
 #endif
 );
 
